.. image:: https://github.com/zhengp0/spmat/workflows/python-build/badge.svg
    :target: https://github.com/zhengp0/spmat/actions

.. image:: https://badge.fury.io/py/spmat.svg
    :target: https://badge.fury.io/py/spmat

Special Matrices
================

A collection of tools for special matrices.
Currently include:

- ``ILMat``: Identity plus PSD low rank matrix.
- ``DLMat``: Diagonal plus PDS low rank matrix.
- ``BDLMat``: Block ``DLMat``.

Install
-------

To install, you could download this repository and,

.. code-block:: bash

    python setup.py install

Or simply install through ``pip``,

.. code-block:: bash

    pip install spmat
